==> kcodecs-4.98.0.zip: kcodecs-4.98.0/src/probers/nsEUCJPProber.h <==
/*  -*- C++ -*-
*  Copyright (C) 1998 <developer@mozilla.org>
*
*
*  Permission is hereby granted, free of charge, to any person obtaining
*  a copy of this software and associated documentation files (the
*  "Software"), to deal in the Software without restriction, including
*  without limitation the rights to use, copy, modify, merge, publish,
*  distribute, sublicense, and/or sell copies of the Software, and to
*  permit persons to whom the Software is furnished to do so, subject to
*  the following conditions:
*
*  The above copyright notice and this permission notice shall be included
*  in all copies or substantial portions of the Software.
*
*  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
*  EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
*  MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
*  NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
*  LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
*  OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
*  WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

// for S-JIS encoding, obeserve characteristic:
// 1, kana character (or hankaku?) often have hight frequency of appereance
// 2, kana character often exist in group
// 3, certain combination of kana is never used in japanese language

#ifndef nsEUCJPProber_h__
#define nsEUCJPProber_h__

#include "nsCharSetProber.h"
#include "nsCodingStateMachine.h"
#include "JpCntx.h"
#include "CharDistribution.h"
namespace kencodingprober
{
class KCODECS_NO_EXPORT nsEUCJPProber: public nsCharSetProber
{
public:
    nsEUCJPProber(void)
    {
        mCodingSM = new nsCodingStateMachine(&EUCJPSMModel);
        Reset();
    };
    virtual ~nsEUCJPProber(void)
    {
        delete mCodingSM;
    };
    nsProbingState HandleData(const char *aBuf, unsigned int aLen);
    const char *GetCharSetName()
    {
        return "EUC-JP";
    };
    nsProbingState GetState(void)
    {
        return mState;
    };
    void      Reset(void);
    float     GetConfidence(void);
    void      SetOpion() {};

protected:
    nsCodingStateMachine *mCodingSM;
    nsProbingState mState;

    EUCJPContextAnalysis mContextAnalyser;
    EUCJPDistributionAnalysis mDistributionAnalyser;

    char mLastChar[2];
};
}

#endif /* nsEUCJPProber_h__ */

==> kcodecs-5.52.0.zip: kcodecs-5.52.0/src/probers/nsEUCJPProber.h <==
/*  -*- C++ -*-
*  Copyright (C) 1998 <developer@mozilla.org>
*
*
*  Permission is hereby granted, free of charge, to any person obtaining
*  a copy of this software and associated documentation files (the
*  "Software"), to deal in the Software without restriction, including
*  without limitation the rights to use, copy, modify, merge, publish,
*  distribute, sublicense, and/or sell copies of the Software, and to
*  permit persons to whom the Software is furnished to do so, subject to
*  the following conditions:
*
*  The above copyright notice and this permission notice shall be included
*  in all copies or substantial portions of the Software.
*
*  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
*  EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
*  MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
*  NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
*  LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
*  OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
*  WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

// for S-JIS encoding, obeserve characteristic:
// 1, kana character (or hankaku?) often have hight frequency of appereance
// 2, kana character often exist in group
// 3, certain combination of kana is never used in japanese language

#ifndef nsEUCJPProber_h__
#define nsEUCJPProber_h__

#include "nsCharSetProber.h"
#include "nsCodingStateMachine.h"
#include "JpCntx.h"
#include "CharDistribution.h"
namespace kencodingprober
{
class KCODECS_NO_EXPORT nsEUCJPProber: public nsCharSetProber
{
public:
    nsEUCJPProber(void)
    {
        mCodingSM = new nsCodingStateMachine(&EUCJPSMModel);
        Reset();
    }
    virtual ~nsEUCJPProber(void)
    {
        delete mCodingSM;
    }
    nsProbingState HandleData(const char *aBuf, unsigned int aLen) override;
    const char *GetCharSetName() override
    {
        return "EUC-JP";
    }
    nsProbingState GetState(void) override
    {
        return mState;
    }
    void      Reset(void) override;
    float     GetConfidence(void) override;
    void      SetOpion() override {};

protected:
    nsCodingStateMachine *mCodingSM;
    nsProbingState mState;

    EUCJPContextAnalysis mContextAnalyser;
    EUCJPDistributionAnalysis mDistributionAnalyser;

    char mLastChar[2];
};
}

#endif /* nsEUCJPProber_h__ */
